"""
:author: Thomas Delaet <thomas@delaet.org>

Port for Domintell
:author: Zilvinas Binisevicius <zilvinas@binis.me>
"""
import logging
import json
import domipy
from domipy.connections import WSSConnection
from domipy.messages.login_request import LoginRequest
from domipy.utils import ModuleJSONEncoder

MODULE_CATEGORIES = {
    'switch': ['VMB4RYLD', 'VMB4RYNO'],
    'sensor': ['VMB6IN', 'VMB7IN']
}

class Controller(object):
    """
    Domintell Bus connection controller
    """

    def __init__(self, address):
        self.logger = logging.getLogger('domintell')
        self.parser = domipy.DomintellParser(self)
        self.__subscribers = []
        self._password = ''
        self._modules = {}
        self.connection = WSSConnection(address, self.parser)

    def feed_parser(self, data):
        """
        Feed parser with new data

        :return: None
        """
        self.parser.feed(data)

    def subscribe(self, subscriber):
        """
        :return: None
        """
        self.__subscribers.append(subscriber)

    def parse(self, message):
        """
        :return: domintell.Message or None
        """
        return self.parser.parse(message)

    def unsubscribe(self, subscriber):
        """
        :return: None
        """
        self.__subscribers.remove(subscriber)

    def send(self, message, callback=None):
        """
        :return: None
        """
        self.connection.send(message, callback)

    def get_modules(self, category):
        """
        Returns a list of modules from a specific category

        :return: list
        """
        result = []
        for module in self._modules.values():
            if module.get_module_name() in MODULE_CATEGORIES[category]:
                result.append(module)
        return result

    def scan(self):
        """
        Scan the bus discovered modules will com to reader thread
        :return: None
        """        
        message = domipy.AppInfoRequest()
        self.send(message)

    def login(self, username, password):
        self._password = password
        message = domipy.LoginRequestSaltCommand(username)
        self.send(message)

    def new_message(self, message):
        """
        :return: None
        """
        self.logger.debug("New message: [%s]",str(message))
        if isinstance(message, domipy.ModuleInfoMessage):
            # do something with module data here
            self.logger.info("Domintell module info message received")
            module_type = message.moduleType
            serial_number = message.serialNumber
            # print(domintell.ModuleRegistry)
            self.add_module(module_type, serial_number)
        elif isinstance(message, domipy.ControllMessage):
            if message.moduleType == 'END APPINFO':
                # all APPINFO received
                logging.info("All APPINFO received")
                # TODO move to config
                with open('modules.js', 'w') as f:
                    m = self._modules
                    # move encoding into config , encoding='iso8859_13'
                    json.dump(m, f, cls=ModuleJSONEncoder)
        elif isinstance(message, domipy.LoginRequestSaltMessage):
            logging.info("Request Salt message received")
            self.send(LoginRequest(message.username, self._password, message.salt, message.nonce))
        
        # forward message to listeners
        for subscriber in self.__subscribers:
            subscriber(message)

    def add_module(self, module_type, serial_number):
        """
        Create and add device
            :param self: 
            :param module_type: 
            :param serial_number: 
        """  
        if module_type in domipy.ModuleRegistry:
            # we support this module
            if serial_number in self._modules:
                # serial numbeer already registered
                pass
            else:
                module = domipy.ModuleRegistry[module_type](serial_number, self)
                self._modules[serial_number] = module
            return self._modules[serial_number]
        else:
            self.logger.warning("!! Module " + module_type + " is not yet supported. !!")
            return None
    
    def get_module(self, serial_number):
        """
        Get device by serial number
        """
        if serial_number in self._modules:
            return self._modules[serial_number]
        else:
            return None

    def stop(self):
        """
        Stop domintell
        """
        self.connection.stop()

    def start_ping(self, ping_interval):
        """
        Start ping service
            :param self: 
            :param ping_interval: 
        """
        self.connection.start_hello(ping_interval)



"""
DMOV01 & DMOV01 module status
PIR movement detector.

:author: Zilvinas Binisevicius <zilvinas@binis.me>
"""
import domipy
from domipy.messages import GenericDIStatusMessage

DMOV_COMMAND_CODE = "DET"

class DMOVStatusMessage(GenericDIStatusMessage):
    """
    DMOV module status
    """
    def __init__(self, address=None):
        GenericDIStatusMessage.__init__(self, 1)
        self.moduleType = DMOV_COMMAND_CODE

domipy.register_command(DMOV_COMMAND_CODE, DMOVStatusMessage)



"""
:author: Zilvinas Binisevicius <zilvinas@binis.me>
"""
import domipy
import domipy.messages
from domipy.messages.temperature_status import COOLING_MESSAGE_DATA_TYPE, HEATING_MESSAGE_DATA_TYPE

DOM_ABSENSE = 1
DOM_AUTO = 2
DOM_COMFORT = 5
DOM_FROST = 6

DOM_REG_MODE_OFF = 0
DOM_REG_MODE_HEATING = 1
DOM_REG_MODE_COOLING = 2
DOM_REG_MODE_MIXED = 3

class DTEM01Module(domipy.Module):
    """
    DTEM01 - temperature controll module (1 channels)
    """
    COMMAND_CODE = 'TE1'

    def __init__(self, serial_number, controller):
        domipy.Module.__init__(self, serial_number, controller)
        self._temperature = None
        self._mode = None
        self._heating_set_point = None
        self._cooling_set_point = None
        self._set_point = None
        self._range = None
        self._regulation_mode = None

    def get_range(self):
        return self._range

    def get_temperature(self):
        return self._temperature
    
    def get_mode(self):
        return self._mode
    
    def get_set_point(self):
        if self._mode == DOM_REG_MODE_HEATING:
            return self._heating_set_point
        else:
            return self._cooling_set_point
        
    def get_heating_set_point(self):
        return self._heating_set_point
    
    def get_cooling_set_point(self):
        return self._cooling_set_point

    def get_regulation_mode(self):
        return self._regulation_mode
        
    def set_temperature(self, temperature):
        if self._mode == DOM_REG_MODE_HEATING:
            message = domipy.SetHeatingTemperatureMessage(self.get_module_code(), self.get_serial_number(), temperature)
        else:
            message = domipy.SetCoolingTemperatureMessage(self.get_module_code(), self.get_serial_number(), temperature)
            
        self._controller.send(message)
    
    def set_mode(self, mode):
        """ Set temperature controll mode, modes:
        0 - off
        1 - heating
        2 - cooling
        3 - mixed
        """
        message = domipy.SetTemperatureModeMessage(self.get_module_code(), self.get_serial_number(), mode)
        self._controller.send(message)

    def set_regulation_mode(self, mode):
        message = domipy.SetRegulationModeMessage(self.get_module_code(), self.get_serial_number(), mode)
        self._controller.send(message)
    
    def set_automatic(self):
        message = domipy.SetTemperatureAutomaticMessage(self.get_module_code(), self.get_serial_number())
        self._controller.send(message)

    def set_absence(self):
        message = domipy.SetTemperatureAbsenceMessage(self.get_module_code(), self.get_serial_number())
        self._controller.send(message)
 
    def set_comfort(self):
        message = domipy.SetTemperatureComfortMessage(self.get_module_code(), self.get_serial_number())
        self._controller.send(message)

    def set_frost(self):
        message = domipy.SetTemperatureFrostMessage(self.get_module_code(), self.get_serial_number())
        self._controller.send(message)

    def number_of_channels(self):
        return 1

    def _on_message(self, message):
        if isinstance(message, domipy.TE1TemperaturetatusMessage):
            self._temperature = message.get_temperature()
            self._heating_set_point = message.get_heating_set_point()
            self._cooling_set_point = message.get_cooling_set_point()
                
            self._mode = self._mode_text_to_number(message.get_mode())
            self._regulation_mode = self._regulation_mode_text_to_number(message.get_regulation_mode())
            self._range = message.get_range()

            for ch in range(0, self.number_of_channels()):
                if ch in self._callbacks:
                    for callback in self._callbacks[ch]:
                        callback(self._temperature, self._mode, self._set_point, self._range)

    def _mode_text_to_number(self, mode):
        if mode == 'AUTO':
            return DOM_AUTO 
        elif mode == 'ABSENCE':
            return DOM_ABSENSE
        elif mode == 'COMFORT':
            return DOM_COMFORT
        elif mode == 'FROST':
            return DOM_FROST
        return DOM_AUTO

    def _regulation_mode_text_to_number(self, regulation_mode):
        if regulation_mode == 'COOLING':
            return DOM_REG_MODE_COOLING
        elif regulation_mode == 'HEATING':
            return DOM_REG_MODE_HEATING
        elif regulation_mode == 'MIXED':
            return DOM_REG_MODE_MIXED
        elif regulation_mode == 'OFF':
            return DOM_REG_MODE_OFF
        
class DTEM02Module(domipy.Module):
    """
    DTEM02 -  controll module (1 channels)    
    """
    COMMAND_CODE = 'TE2'
    def _on_message(self, message):
        if isinstance(message, domipy.TE2TemperaturetatusMessage):
            self._temperature = message.get_temperature()
            if(message.get_dataType() == HEATING_MESSAGE_DATA_TYPE): 
                self._set_point = message.get_heating_set_point()
            else:
                self._set_point = message.get_cooling_set_point()
            self._mode = message.get_mode()
            self._range = message.get_range()

            for ch in range(0, self.number_of_channels()):
                if ch in self._callbacks:
                    for callback in self._callbacks[ch]:
                        callback(self._temperature, self._mode, self._set_point, self._range)

domipy.register_module_class(DTEM01Module)
domipy.register_module_class(DTEM02Module)



"""
Simulate digital inputs
:author: Zilvinas Binisevicius <zilvinas@binis.me>
"""
import domipy


class DigitalShortPush(domipy.Command):
    """Simulate SHORT signal on digital input"""
    def __init__(self, moduleType, serialNumber):
        domipy.Command.__init__(self, moduleType, serialNumber, "%P1")

class DigitalLongPush(domipy.Command):
    """Simulate LONG signal on digital input"""
    def __init__(self, moduleType, serialNumber):
        domipy.Command.__init__(self, moduleType, serialNumber, "%P3")

class DigitalShortPushEnd(domipy.Command):
    """Simulate End of Short signal on digital input"""
    def __init__(self, moduleType, serialNumber):
        domipy.Command.__init__(self, moduleType, serialNumber, "%P2")

class DigitalLongPushEnd(domipy.Command):
    """Simulate End of Long signal on digital input"""
    def __init__(self, moduleType, serialNumber):
        domipy.Command.__init__(self, moduleType, serialNumber, "%P4")


"""
:author: Thomas Delaet <thomas@delaet.org>

Port for Domintell
:author: Zilvinas Binisevicius <zilvinas@binis.me>
"""
import json
import base64
import domipy


class Message(object):
    # pylint: disable-msg=R0904
    """
    Base Domintell message
    """

    def __init__(self, moduleType=None, serialNumber=None):
        self.moduleType = moduleType
        self.serialNumber = serialNumber
        self.dataType = None
        self.data = None

    def set_attributes(self, module_type, serial_number, data_type, data):
        """
        :return: None
        """
        assert isinstance(module_type, str)
        assert isinstance(serial_number, str)
        assert isinstance(data_type, str)
        assert isinstance(data, str)
        self.moduleType = module_type
        self.serialNumber = serial_number
        self.dataType = data_type
        self.data = data

    def populate(self, serial_number, data_type, data_string):
        """
        :return: None
        """
        raise NotImplementedError

    def get_values(self):
        raise NotImplementedError

    def to_json_basic(self):
        """
        Create JSON structure with generic attributes

        :return: dict
        """
        return {'name': self.__class__.__name__, 'module_type': self.moduleType,
                'serial_number': self.serialNumber, 'data_type': self.dataType}

    def to_string(self):
        """
        Convert to domintell controll string

        This method may be overridden in subclasses to include more than just generic attributes

        :return: str
        """
        return "{}{}".format(self.moduleType, self.serialNumber)

    def to_json(self):
        """
        Dump object structure to JSON

        This method should be overridden in subclasses to include more than just generic attributes

        :return: str
        """
        return json.dumps(self.to_json_basic())

    def __str__(self):
        return self.to_json()

    def parser_error(self, message):
        """
        :return: None
        """
        raise domipy.ParserError(self.__class__.__name__ + " " + message)
    
    def is_binary(self):
        return False




import json
from json import JSONEncoder
from domipy.module import Module
from decimal import Decimal

class ModuleJSONEncoder(JSONEncoder):
    """
    Convert module to json
    """
    #pylint: disable=E0202
    def default(self, obj):
        if issubclass(obj.__class__, Module):
            return obj.to_json_basic()
        return JSONEncoder.default(self, obj)


class DecimalEncoder(json.JSONEncoder):
    #pylint: disable=E0202
    def default(self, obj):
        if isinstance(obj, Decimal):
            return float(obj)
        return json.JSONEncoder.default(self, obj)


"""
DTSC0xodule status
Touch screen.

:author: Zilvinas Binisevicius <zilvinas@binis.me>
"""
import json
import domipy
from domipy.messages import GenericDIStatusMessage
from decimal import Decimal
from domipy.utils import DecimalEncoder

DTSC_COMMAND_CODE = "TSB"

class DTSCStatusMessage(GenericDIStatusMessage):
    """
    DISM4 module status
    """

    def __init__(self, address=None):
        GenericDIStatusMessage.__init__(self, 4)
        self.moduleType = DTSC_COMMAND_CODE
        self.current = None
        self.mode = None
        self.setPoint = None
        self.range = None

    def populate(self, serialNumber, dataType, dataString):
        """
        :return: None
        """
        # assert isinstance(dataString, str)
        self.serialNumber = serialNumber

        if dataType == "I":
            mask = int(dataString[0:2].strip(), 16)
            for input in range(0, self.inputCount):
                self.inputs[input] = 1 if (mask & (input + 1)) else 0
        elif dataType == "T":
            data = dataString.split()
            self.current = Decimal(data[0])
            self.setPoint = Decimal(data[1])
            self.mode = data[2]
            self.range = Decimal(data[3])

    def to_json(self):
        """
        :return: str
        """
        json_dict = self.to_json_basic()
        for input in range(0, self.inputCount):
            if input < len(self.inputs):
                json_dict['input{}'.format(input)] = self.inputs[input]
        
        json_dict['current'] = DecimalEncoder().encode(self.current)
        json_dict['mode'] = self.mode
        json_dict['setPoint'] = DecimalEncoder().encode(self.setPoint)
        json_dict['range'] = DecimalEncoder().encode(self.range)
        return json.dumps(json_dict)


domipy.register_command(DTSC_COMMAND_CODE, DTSCStatusMessage)



"""
:author: Zilvinas Binisevicius <zilvinas@binis.me>
"""
import domipy


class SetAnalogOutputMessage(domipy.Command):

    def __init__(self, module_type, serial_number, channel=0, value=0):
        domipy.Command.__init__(self, module_type, serial_number, channel, "%D", value)




"""
:author: Thomas Delaet <thomas@delaet.org>
"""
# pylint: disable-msg=C0301
# appifo scan messages and system messages
from domipy.messages.appinfo_request import AppInfoRequest
from domipy.messages.module_info import ModuleInfoMessage
from domipy.messages.ping import Ping
from domipy.messages.hello import Hello
from domipy.messages.login_request_salt import LoginRequestSaltCommand
from domipy.messages.login_request_salt import LoginRequestSaltMessage
from domipy.messages.waiting_for_loginsw import WaitingForLoginswMessage
from domipy.messages.login_request import LoginRequest
from domipy.messages.info import InfoMessage
from domipy.messages.control import ControllMessage
from domipy.messages.session_closed import SessionClosedMessage
from domipy.messages.session_opened import SessionOpenedMessage
from domipy.messages.session_timeout import SessionTimeoutMessage
# status messages
from domipy.messages.ai_status import GenericAIStatusMessage
from domipy.messages.ao_status import GenericAOStatusMessage
from domipy.messages.do_status import GenericDOStatusMessage
from domipy.messages.di_status import GenericDIStatusMessage
from domipy.messages.dio_status import GenericDIOStatusMessage
from domipy.messages.dbir_status import DBIRStatusMessage
from domipy.messages.dmr_status import DDMRStatusMessage
from domipy.messages.ddim_status import DDIMStatusMessage
from domipy.messages.din10v_status import DIN10VStatusMessage
from domipy.messages.dism_status import DISM4StatusMessage
from domipy.messages.dism_status import DISM8StatusMessage
from domipy.messages.dmov_status import DMOVStatusMessage
from domipy.messages.dpbu_status import DPBU01StatusMessage
from domipy.messages.dpbu_status import DPBU02StatusMessage
from domipy.messages.dpbu_status import DPBU04StatusMessage
from domipy.messages.dpbu_status import DPBU06StatusMessage
from domipy.messages.dtrp_status import DTRPStatusMessage
from domipy.messages.dtrv_status import DTRVStatusMessage
from domipy.messages.dtrv_status import DTRVBTStatusMessage
from domipy.messages.dtsc_status import DTSCStatusMessage
from domipy.messages.module_status_request import ModuleStatusRequest
from domipy.messages.dled_status  import DLEDStatusMessage
# Command messages
from domipy.messages.set_ao import SetAnalogOutputMessage
from domipy.messages.set_di import DigitalShortPush
from domipy.messages.set_di import DigitalLongPush
from domipy.messages.set_di import DigitalShortPushEnd
from domipy.messages.set_di import DigitalLongPushEnd
from domipy.messages.set_dimmer import SetDimmer
from domipy.messages.set_dimmer import StartDimmer
from domipy.messages.set_dimmer import StopDimmer
from domipy.messages.set_dimmer import IncrementDimmer
from domipy.messages.set_dimmer import DecrementDimmer
from domipy.messages.set_do import SetDigitalOutputMessage
from domipy.messages.set_do import SetDigitalOutputOnMessage
from domipy.messages.set_do import SetDigitalOutputOffMessage
from domipy.messages.set_do import TogleDigitalOutputMessage
from domipy.messages.set_do import SetDigitalOutputOpenMessage
from domipy.messages.set_do import SetDigitalOutputCloseMessage
from domipy.messages.set_do import SetDigitalOutputStopMessage
from domipy.messages.set_temperature import SetHeatingTemperatureMessage
from domipy.messages.set_temperature import SetCoolingTemperatureMessage
from domipy.messages.set_temperature import SetTemperatureModeMessage
from domipy.messages.set_temperature import SetTemperatureSetPointMessage
from domipy.messages.set_temperature import SetCoolingTemperatureSetPointMessage
from domipy.messages.set_temperature import SetTemperatureComfortMessage
from domipy.messages.set_temperature import SetTemperatureAutomaticMessage
from domipy.messages.set_temperature import SetTemperatureAbsenceMessage
from domipy.messages.set_temperature import SetTemperatureFrostMessage
from domipy.messages.set_temperature import SetRegulationModeMessage

from domipy.messages.temperature_status import TE1TemperaturetatusMessage
from domipy.messages.temperature_status import TE2TemperaturetatusMessage
from domipy.messages.var_status import VARStatusMessage
from domipy.messages.var_status import SYSStatusMessage
from domipy.messages.set_var import SwitchValueMessage
from domipy.messages.user_disconnected import UserDisconnected


"""
:author: Thomas Delaet <thomas@delaet.org>

Port for Domintell
:author: Zilvinas Binisevicius <zilvinas@binis.me>

"""
import socket
import time
import threading
import logging
from queue import Queue
import ssl
import serial
import serial.threaded
import websocket
import domipy

class Protocol(serial.threaded.Protocol):
    """Serial protocol."""

    def data_received(self, data):
        # pylint: disable-msg=E1101
        self.parser(data)


class DomintellException(Exception):
    """Domintell Exception."""
    def __init__(self, value):
        Exception.__init__(self)
        self.value = value

    def __str__(self):
        return repr(self.value)

class DomintellConnection():
    """
    Generic Domintell connection
    """
    def send(self, message, callback=None):
        """
        :return: None
        """
        raise NotImplementedError

class WSSConnection(DomintellConnection):
    """
        Wrapper for Secure Web Socket connection configuration
    """
    def __init__(self, address, parser=None, hello_interval=0):
        DomintellConnection.__init__(self)
        self.logger = logging.getLogger('domintell')
        self._address = address
        self.parser = parser
        self.hello_interval = hello_interval
        self.is_connected = False
        self.reconnect_interval = 30

        self.connect_socket()
        # build a read thread
        self._listen_process = threading.Thread(None, self.read_daemon,
                                         "domintell-process-reader", (), {})
        self._listen_process.daemon = True
        self._listen_process.start()

        # build a writer thread
        self._write_queue = Queue()
        self._write_process = threading.Thread(None, self.write_daemon,
                                               "domintell-connection-writer", (), {})
        self._write_process.daemon = True
        self._write_process.start()

        # build a ping thread
        self._hello_process = threading.Thread(None, self.hello_daemon,
                                            "domintell-ping-writer", (), {})
        self._hello_process.daemon = True

    def connect_socket(self):
        try:
            self._socket = websocket.WebSocket(sslopt={"cert_reqs": ssl.CERT_NONE})
            self._socket.connect(self._address)
            self.is_connected = True

        except OSError as osError:
            self.is_connected = False
            if osError.strerror == 'A socket operation was attempted to an unreachable host' :
                self.logger.error("Could not open socket, host is unreacheble")
                time.sleep(self.reconnect_interval)
            else:
                self.logger.error("Could not open socket, \
                              no messages are read or written to the bus")
                raise DomintellException("Could not open socket port") from osError
                
        except Exception as ex:
            self.is_connected = False
            self.logger.error("Could not open socket, \
                              no messages are read or written to the bus")
            raise DomintellException("Could not open socket port") from ex

    def stop(self):
        """Close socket."""
        self.logger.warning("Stop executed")
        try:
            self._socket.close()
        except Exception as ex:
            self.logger.error("Error while closing socket")
            raise DomintellException("Error while closing socket") from ex
        time.sleep(1)

    def feed_parser(self, data):
        """Parse received message."""
        
        if(data.startswith("TE1")):
            self.parser.feed(data)
        else:
            lines = data.splitlines()
            for line in lines:
                self.parser.feed(data)

    def send(self, message, callback=None):
        """Add message to write queue."""
        assert isinstance(message, domipy.Message)
        self._write_queue.put_nowait((message, callback))

    def read_daemon(self):
        """Reads incoming data."""
        while True:
            try:
                data = self._socket.recv()
                self.feed_parser(data)
            except websocket.WebSocketConnectionClosedException :
                self.logger.warning("Read Deamon, connection closed")
                self.connect_socket() 

    def write_daemon(self):
        """Write thread."""
        while True:
            (message, callback) = self._write_queue.get(block=True)
            self.logger.info("Sending message to socket: %s", str(message))
            self.logger.debug("Sending controll message:  %s", message.to_string())
            try:
                if message.is_binary():
                    self._socket.send(message.to_string())
                else:
                    self._socket.send(bytes(message.to_string(),'ascii'))
            except websocket.WebSocketConnectionClosedException :
                self.logger.warning("Write Deamon, connection closed")
                self.connect_socket()

            time.sleep(0.3)
            if callback:
                callback()

    def hello_daemon(self):
        """Put hello message into write thread every hello_interval sec"""
        while True:
            ping_message = domipy.messages.Hello()
            self.send(ping_message)
            time.sleep(self.hello_interval)

    def start_hello(self, interval=-1):
        """
        Start sending HELLO message to server every minute.
        Server will end Login 'session' if no messages received
        in predefined interval (10mins default)
        """
        if interval > -1:
            self.hello_interval = interval

        if self.hello_interval > 0:
            if not self._hello_process.is_alive():
                self._hello_process.start()



import json
import domipy


class LoginRequestSaltCommand(domipy.Command):
    """
        send: REQUESTSALT@<username>
    """
    def __init__(self, username):
        domipy.Command.__init__(self, "REQUESTSALT@", "REQUESTSALT@")
        self._username = username

    def command(self): 
        return "REQUESTSALT@" + self._username

    def is_binary(self):
        return True

class LoginRequestSaltMessage(domipy.Message):
    """
    Session opened message
    """

    def __init__(self, moduleType=None, data=None):
        domipy.Message.__init__(self)
       
        self.moduleType = 'REQUESTSALT'
        self.username = data[2].split('=')[1]
        self.nonce = data[3].split('=')[1]
        self.salt = data[4].split("=")[1]
        self._message = data
    
    def populate(self, serialNumber, dataType, dataString):
        pass

    def to_json(self):
        """
        :return: str
        """
        json_dict = self.to_json_basic()
        json_dict['username'] = self.username
        json_dict['nounce'] = self.nonce
        json_dict['salt'] = self.salt
        return json.dumps(json_dict)



"""
BIR module status
Output card to control 8 250V/8A two-pole relays.

:author: Zilvinas Binisevicius <zilvinas@binis.me>
"""
import json
import domipy
from domipy.messages import GenericDOStatusMessage

LED_COMMAND_CODE = "LED"

class DLEDStatusMessage(GenericDOStatusMessage):
    """
    DBIR module status
    """

    def __init__(self, address=None):
        GenericDOStatusMessage.__init__(self, 4)
        self.moduleType = LED_COMMAND_CODE

domipy.register_command(LED_COMMAND_CODE, DLEDStatusMessage)
